@@ -1,13 +1,10 @@
-use structopt::StructOpt;
+use structopt::{clap::AppSettings::DeriveDisplayOrder, StructOpt};
 
 #[derive(StructOpt)]
-#[structopt(name = "printimg")]
+#[structopt(name = "printimg", setting(DeriveDisplayOrder))]
 pub struct Opt {
     #[structopt(name = "PATH")]
-    pub path: String,
-
-    #[structopt(short, long)]
-    pub verbose: bool,
+    pub path: Option<String>,
 
     /// Rotate counterclockwise
     #[structopt(short, long)]
@@ -20,4 +17,11 @@ pub struct Opt {
     /// Disable super resolution
     #[structopt(short, long)]
     pub flat: bool,
+
+    #[structopt(short, long)]
+    pub verbose: bool,
+
+    /// Prints build information of OpenCV
+    #[structopt(short, long, conflicts_with = "PATH")]
+    pub build_info: bool,
 }
